@@ -24,11 +24,11 @@ import toml
 
 from . import terminal, database
 from .xdict import XDict
-from .tools import rotate, grouper, read_text
+from .tools import rotate, grouper, read_text, fracdigits_nb, turn_to_capwords
 from .configfile import StandardConfigFile
 
 with open(Path(__file__).parent / 'meta/pyproject.toml', 'r') as f:
     __version__ = toml.load(f)['tool']['poetry']['version']
 
 __all__ = [terminal, XDict, rotate, grouper, read_text, StandardConfigFile,
-           database]
+           database, fracdigits_nb, turn_to_capwords]
